"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClusterManager = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const redis_errors_1 = require("redis-errors");
const cluster_constants_1 = require("./cluster.constants");
const messages_1 = require("../messages");
const utils_1 = require("../utils");
let ClusterManager = class ClusterManager {
    constructor(clusterClients) {
        this.clusterClients = clusterClients;
    }
    /**
     * Gets all cluster clients as a read-only map.
     */
    get clients() {
        return this.clusterClients;
    }
    /**
     * Gets cluster client via namespace.
     */
    getClient(namespace = cluster_constants_1.DEFAULT_CLUSTER_NAMESPACE) {
        const client = this.clusterClients.get(namespace);
        if (!client)
            throw new redis_errors_1.RedisError((0, messages_1.CLIENT_NOT_FOUND)((0, utils_1.parseNamespace)(namespace), false));
        return client;
    }
};
ClusterManager = (0, tslib_1.__decorate)([
    (0, common_1.Injectable)(),
    (0, tslib_1.__param)(0, (0, common_1.Inject)(cluster_constants_1.CLUSTER_CLIENTS)),
    (0, tslib_1.__metadata)("design:paramtypes", [Object])
], ClusterManager);
exports.ClusterManager = ClusterManager;
