"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClusterToken = exports.InjectCluster = exports.namespaces = void 0;
const common_1 = require("@nestjs/common");
const cluster_constants_1 = require("../cluster.constants");
const utils_1 = require("../../utils");
exports.namespaces = new Map();
/**
 * Decorator that injects a cluster client to the constructor parameter.
 *
 * @param namespace - The name of the client
 */
const InjectCluster = (namespace = cluster_constants_1.DEFAULT_CLUSTER_NAMESPACE) => {
    if ((0, utils_1.isString)(namespace)) {
        const token = (0, exports.getClusterToken)(namespace);
        exports.namespaces.set(namespace, token);
        return (0, common_1.Inject)(token);
    }
    exports.namespaces.set(namespace, namespace);
    return (0, common_1.Inject)(namespace);
};
exports.InjectCluster = InjectCluster;
/**
 * Generates an injection token for a cluster client.
 *
 * @param namespace  - The name of the client
 */
const getClusterToken = (namespace) => {
    if ((0, utils_1.isSymbol)(namespace))
        return namespace;
    return `${cluster_constants_1.CLUSTER_MODULE_ID}:${namespace}`;
};
exports.getClusterToken = getClusterToken;
