"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.quitClients = exports.displayReadyLog = exports.createClient = void 0;
const tslib_1 = require("tslib");
const ioredis_1 = (0, tslib_1.__importDefault)(require("ioredis"));
const promise_allsettled_1 = (0, tslib_1.__importDefault)(require("promise.allsettled"));
const cluster_constants_1 = require("../cluster.constants");
const utils_1 = require("../../utils");
const messages_1 = require("../../messages");
const cluster_logger_1 = require("../cluster-logger");
const createClient = (clientOptions) => {
    const { nodes, options, onClientCreated } = clientOptions;
    const client = new ioredis_1.default.Cluster(nodes, options);
    if (onClientCreated)
        onClientCreated(client);
    return client;
};
exports.createClient = createClient;
const displayReadyLog = (clients) => {
    clients.forEach((client, namespace) => {
        client.once(cluster_constants_1.ClusterStatus.READY, () => {
            cluster_logger_1.logger.log(`${(0, utils_1.parseNamespace)(namespace)}: ${messages_1.CONNECTED_SUCCESSFULLY}`);
        });
    });
};
exports.displayReadyLog = displayReadyLog;
const quitClients = (clients) => {
    const promises = [];
    clients.forEach((client, namespace) => {
        if (client.status === cluster_constants_1.ClusterStatus.READY) {
            promises.push((0, promise_allsettled_1.default)([Promise.resolve(namespace), client.quit()]));
            return;
        }
        client.disconnect();
    });
    return Promise.all(promises);
};
exports.quitClients = quitClients;
