import { HealthIndicator, HealthIndicatorResult } from '@nestjs/terminus';
import { Redis, Cluster } from 'ioredis';
export interface RedisCheckOptions {
    /**
     * The client which the health check should get executed.
     */
    client: Redis | Cluster;
}
export declare class RedisHealthIndicator extends HealthIndicator {
    /**
     * Checks a redis/cluster connection.
     *
     * @param key - The key which will be used for the result object
     * @param options - The options for check
     *
     * @example
     * ```
     * import IORedis from 'ioredis';
     *
     * const client = new IORedis({ host: '127.0.0.1', port: 6380 });
     * indicator.checkHealth('redis', { client });
     * ```
     *
     * @example
     * ```
     * import IORedis from 'ioredis';
     *
     * const client = new IORedis.Cluster([{ host: '127.0.0.1', port: 16380 }]);
     * indicator.checkHealth('cluster', { client });
     * ```
     */
    checkHealth(key: string, options: RedisCheckOptions): Promise<HealthIndicatorResult>;
}
