"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRedisToken = exports.InjectRedis = exports.namespaces = void 0;
const common_1 = require("@nestjs/common");
const redis_constants_1 = require("../redis.constants");
const utils_1 = require("../../utils");
exports.namespaces = new Map();
/**
 * Decorator that injects a redis client to the constructor parameter.
 *
 * @param namespace - The name of the client
 */
const InjectRedis = (namespace = redis_constants_1.DEFAULT_REDIS_NAMESPACE) => {
    if ((0, utils_1.isString)(namespace)) {
        const token = (0, exports.getRedisToken)(namespace);
        exports.namespaces.set(namespace, token);
        return (0, common_1.Inject)(token);
    }
    exports.namespaces.set(namespace, namespace);
    return (0, common_1.Inject)(namespace);
};
exports.InjectRedis = InjectRedis;
/**
 * Generates an injection token for a redis client.
 *
 * @param namespace  - The name of the client
 */
const getRedisToken = (namespace) => {
    if ((0, utils_1.isSymbol)(namespace))
        return namespace;
    return `${redis_constants_1.REDIS_MODULE_ID}:${namespace}`;
};
exports.getRedisToken = getRedisToken;
