"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedisManager = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const redis_errors_1 = require("redis-errors");
const redis_constants_1 = require("./redis.constants");
const messages_1 = require("../messages");
const utils_1 = require("../utils");
let RedisManager = class RedisManager {
    constructor(redisClients) {
        this.redisClients = redisClients;
    }
    /**
     * Gets all redis clients as a read-only map.
     */
    get clients() {
        return this.redisClients;
    }
    /**
     * Gets redis client via namespace.
     */
    getClient(namespace = redis_constants_1.DEFAULT_REDIS_NAMESPACE) {
        const client = this.redisClients.get(namespace);
        if (!client)
            throw new redis_errors_1.RedisError((0, messages_1.CLIENT_NOT_FOUND)((0, utils_1.parseNamespace)(namespace)));
        return client;
    }
};
RedisManager = (0, tslib_1.__decorate)([
    (0, common_1.Injectable)(),
    (0, tslib_1.__param)(0, (0, common_1.Inject)(redis_constants_1.REDIS_CLIENTS)),
    (0, tslib_1.__metadata)("design:paramtypes", [Object])
], RedisManager);
exports.RedisManager = RedisManager;
